function X = appll_sw_postm(theta0)
%We use this function to compute posterior mode/Hessian
%when steady states are estimated  - Full Spectrum and Mean are both used.

%Remember for parameter estimation we specify w from 1 to T-1
%This likelihood should be minimized to obtain the estimator
%Note that theta0 is 36x1 as 5 parameters are fixed
cgy=theta0(1);
cmaw=theta0(2);
cmap=theta0(3);
calfa=theta0(4);
czcap=theta0(5);
csadjcost=theta0(6);
csigma=theta0(7);
chabb=theta0(8);
cfc=theta0(9);
cindw=theta0(10);
cprobw=theta0(11);
cindp=theta0(12);
cprobp=theta0(13);
csigl=theta0(14);
crpi=theta0(15);
crdy=theta0(16);
cry=theta0(17);
crr=theta0(18);
crhoa=theta0(19);
crhob=theta0(20);
crhog=theta0(21);
crhoqs=theta0(22);
crhoms=theta0(23);
crhopinf=theta0(24);
crhow=theta0(25);
sigma_a=theta0(26);
sigma_b=theta0(27);
sigma_g=theta0(28);
sigma_qs=theta0(29);
sigma_m=theta0(30);
sigma_pinf=theta0(31);
sigma_w=theta0(32);
cgamma=(theta0(33)/100)+1; %note the initial parameterization as in SW Table 1a
cbeta=100/(theta0(34)+100);%
constepinf=theta0(35); %these last two enter SS only
constelab=theta0(36);
ctou=0.025; %fixed parameters as in SW
cg=0.18;
clandaw=1.5;
curvp=10;
curvw=10;
%SS parameters
cpie=1+constepinf/100;
cr=cpie/(cbeta*cgamma^(-csigma));
conster=(cr-1)*100; %r-bar for SS

load sw07measurementdata
stobs=71; %starting at the same data as SW
x=sw07dat(stobs:end,:); %remove pre-1960 data

n=length(x);
mu=kron([theta0(33)*ones(1,3),constelab,constepinf,theta0(33),conster],ones(n,1)); %mu term for frequency zero component
w=2*pi*(1:1:230-stobs)'/n; %frequencies for approximate (Whittle) log likelihood
%compute parameters derived from steady state
ssdpar; %see ssdpar.m
%% 
% % number equations
eqvarshock;  %see eqvarshock.m

%%
setsimsmat; %get sims representation
%% call gensys
[T1,TC,T0,M,TZ,TY,GEV,RC] = gensys(GAM0,GAM1,CS,PSI,PPI);

%if RC~=[1;1]
%    X=-0.01; %penalize if indeterminacy
%else

%sample periodograms  and cross-periodograms
s=size(x);
T=s(1); %determine sample size
ny=s(2); %number of variables
pervec=zeros(T,ny^2); %blank
for i=1:ny
for j=1:ny
    pervec(:,j+(i-1)*ny)=periodogram({x(:,i),x(:,j)},rectwin(T),T); %(cross)periodograms across possibe Fourier frequencies in vech from
end
end
pervec=pervec(2:end,:); %get rid of frequency 0

%prepare stuf to compute spectrum
matB=eye(neq);
matA=matB(18:24,:);
term1=0;  %initialize terms 1 and 2 for cumulative summation
term2=0;
i=1;
while i<=length(w); %compute spectrum (see gmatrix.m for details)
exe=exp(-1i*w(i));
matA(:,[18:20,23])=matA(:,[18:20,23])*(1-exe);
fact1=matA*((eye(neq) - T1*exe)\T0);
ftheta=(1/(2*pi))*(fact1*fact1'); %compute spectrum using representation (4) in the paper
term1=term1+log(det(ftheta)); %first term in the Whittle likelihood
pd=reshape(pervec(i,:),ny,ny).'; %sample periodogram matrix at w(i)
term2=term2+trace(ftheta\pd); %second term in the likelihood

matA=matB(18:24,:); %restore initial A
i=i+1;
end
WL1=0.5*(real(term1+term2)); %small complex residual of order e-15i sometimes remains
lp=logprm(theta0); %compute minus log prior density
%now to frequency zero
ydm=sum(x-mu)'; %sum of demeaned data
pd0=(1/(2*pi*n))*ydm*ydm';
matA(:,[18:20,23])=matA(:,[18:20,23])*0;
fact0=matA*((eye(neq) - T1)\T0);
f0=(1/(2*pi))*(fact0*fact0'); %spectrum at freq 0
%now deal with singularity issues
eig0=eig(f0);
det0=eig0(5)*eig0(6)*eig0(7);%*(1e-05^4); %determinant as a product of eigenvalues, throwing out those equal to zero
WL2=log(det0)+trace(pinv(f0)*pd0); %use pseudo-inverse
WL2=0.5*WL2;
% [eiv0 eig0]=eig(f0);
% eig0(1:4,1:4)=eye(4)*1e-05;
% invf0=eiv0*inv(eig0)*eiv0';
% det0=eig0(5,5)*eig0(6,6)*eig0(7,7)*(1e-05^4); %determinant as a product of eigenvalues, throwing out those equal to zero
% WL2=log(det0)+trace(invf0*pd0); %use pseudo-inverse
X=WL1+WL2+lp; %final answer: minus log posterior
%end
end
