function X = drawprior(n)
%Makes a draw of a parameter vector from the priors from  Table 1a in SW(2007)

%index priors by 1 - Beta, 2 - Gamma, 3 - Normal, 4 - Invgamma
%priorind=[1,1,1,3,1,3,3,1,3,1,1,1,1,3,3,3,3,1,1,1,1,1,1,1,1,4,4,4,4,4,4,4,3,2]';
priorind=[3,1,1,3,1,3,3,1,3,1,1,1,1,3,3,3,3,1,1,1,1,1,1,1,1,4,4,4,4,4,4,4,3,2]'; %SW dynare
%Use SW07 prior parameters. Note the first is mean, the second - std. dev.
%Note we fix the same parameters as SW07
%So in the dynamic case here n=34
%Select the means and the std. dev.'s of the prior distributions, as in
%SW07
swparm=[0.5,0.25;0.5,0.2;0.5,0.2;0.3,0.05;0.5,0.15;4,1.5;1.5,0.375;0.7,0.1;1.25,0.125;0.5,0.15;...
    0.5,0.10;0.5,0.15;0.5,0.10;2,0.75;1.5,0.25;0.125,0.05;0.125,0.05;0.75,0.1;0.5,0.2;0.5,0.2;...
    0.5,0.2;0.5,0.2;0.5,0.2;0.5,0.2;0.5,0.2;0.1,2;0.1,2;0.1,2;0.1,2;0.1,2;0.1,2;0.1,2;0.4,0.1;...
    0.25,0.1]; %note  here we use gammabar and 100*(1/b - 1) instead of cgamma and cbeta in the identification code.
%just for the sake of convenient evaluation of the log prior density
%create blanks
X=zeros(1,n); %blank
a = 0;
b = 0;
for i=1:n

	shape = priorind(i); %determine pdf shape
	para1 = swparm(i,1);
	para2 = swparm(i,2);

	% BETA prior
	if shape==1
		a = (1-para1)*para1^2/para2^2 - para1;
		b = a*(1/para1 - 1);
		X(i) = betarnd(a,b,1,1);

	% GAMMA prior
	elseif shape==2
		b = para2^2/para1;
		a = para1/b;
		X(i) = gamrnd(a,b,1,1);

	% NORMAL prior
	elseif shape==3
		a = para1;
		b = para2;
		X(i) = para1+randn(1,1)*para2;

	% INVGAMMA prior
	elseif shape==4
		a = (para1^2)/(para2^2) +2;
		b = (a-1)*para1;
		X(i) = 1/gamrnd(a,1/b,1,1);

	end;
end;




