function lp = logprm(theta)
%Computes log-likelihood of the prior for SW07 model. 
%Dimension of theta is 36x1 (last 5 parameters are fixed)
%Some code here is borrowed from An and Schorfheide's (2007) (or AS(2007))
%logprior.m file
%Note this is for estimation including both the mean and spectrum

n  = length(theta);
%index priors by 1 - Beta, 2 - Gamma, 3 - Normal, 4 - Invgamma
%priorind=[1,1,1,3,1,3,3,1,3,1,1,1,1,3,3,3,3,1,1,1,1,1,1,1,1,4,4,4,4,4,4,4,3,2]'; %SW paper
priorind=[3,1,1,3,1,3,3,1,3,1,1,1,1,3,3,3,3,1,1,1,1,1,1,1,1,4,4,4,4,4,4,4,3,2,2,3]'; %SW dynare
%priorind=[3,1,1,3,1,3,1,3,1,1,1,1,3,3,3,3,1,1,1,1,1,1,1,1,4,4,4,4,4,4,4]'; %SW dynare for fixed ss params
%Use SW07 prior parameters. Note the first is mean, the second - std. dev.
%Note we fix the same parameters as SW07
%So in the dynamic case here n=35
%Select the means and the std. dev.'s of the prior distributions, as in
%SW07 Table 1
%swparm=[0.5,0.2;0.5,0.2;0.5,0.2;0.3,0.05;0.5,0.15;4,1.5;1.5,0.37;0.7,0.1;1.25,0.12;0.5,0.15;...
 %   0.5,0.10;0.5,0.15;0.5,0.10;2,0.75;1.5,0.25;0.12,0.05;0.12,0.05;0.75,0.1;0.5,0.2;0.5,0.2;...
  %  0.5,0.2;0.5,0.2;0.5,0.2;0.5,0.2;0.5,0.2;0.1,2;0.1,2;0.1,2;0.1,2;0.1,2;0.1,2;0.1,2;0.4,0.1;...
   % 0.25,0.1]; %note here we use gammabar and 100*(1/b - 1) instead of cgamma and cbeta in the identification code.
%Select the means and the std. dev.'s of the prior distributions, as in
%SW07 dynare code
swparm=[0.5,0.25;0.5,0.2;0.5,0.2;0.3,0.05;0.5,0.15;4,1.5;1.5,0.375;0.7,0.1;1.25,0.125;0.5,0.15;...
    0.5,0.10;0.5,0.15;0.5,0.10;2,0.75;1.5,0.25;0.125,0.05;0.125,0.05;0.75,0.1;0.5,0.2;0.5,0.2;...
    0.5,0.2;0.5,0.2;0.5,0.2;0.5,0.2;0.5,0.2;0.1,2;0.1,2;0.1,2;0.1,2;0.1,2;0.1,2;0.1,2;0.4,0.1;...
    0.25,0.1;0.625,0.1;0,2]; %note 
% swparm=[0.5,0.25;0.5,0.2;0.5,0.2;0.3,0.05;0.5,0.15;4,1.5;0.7,0.1;1.25,0.125;0.5,0.15;...
%     0.5,0.10;0.5,0.15;0.5,0.10;2,0.75;1.5,0.25;0.125,0.05;0.125,0.05;0.75,0.1;0.5,0.2;0.5,0.2;...
%     0.5,0.2;0.5,0.2;0.5,0.2;0.5,0.2;0.5,0.2;0.1,2;0.1,2;0.1,2;0.1,2;0.1,2;0.1,2;0.1,2]; %for fixed ss params
%create blanks
y = 0;
a = 0;
b = 0;
for i=1:n

	shape = priorind(i); %determine pdf shape
	para1 = swparm(i,1);
	para2 = swparm(i,2);

	% BETA prior
	if shape==1
		a = (1-para1)*para1^2/para2^2 - para1;
		b = a*(1/para1 - 1);
		y = y + lnpdfbeta(theta(i),a,b);

	% GAMMA prior
	elseif shape==2
		b = para2^2/para1;
		a = para1/b;
		y = y + lnpdfgam(theta(i),a,b);

	% NORMAL prior
	elseif shape==3
		a = para1;
		b = para2;
		y = y + lnpdfnorm(theta(i),a,b);

	% INVGAMMA prior
	elseif shape==4
		a = para1;
		b = para2;
		y = y + lnpdfig(theta(i),a,b);

    end
    lp=-y; %minus the log prior density
end




%
% logs of density functions
%
%These functions borrowed from AS(2007)
% beta
function y=lnpdfbeta(x,a,b)
% LNPDFBETA(X,A,B)
%	calculates log BETA(A,B) at X

% Sungbae An
% 03/03/2002
y = gammaln(a+b) - gammaln(a) - gammaln(b) + (a-1)*log(x) + (b-1)*log(1-x);

% gamma
function y=lnpdfgam(x,a,b)
% LNPDFGAM(X,A,B)
%	calculates log GAMMA(A,B) at X

% 03/03/2002
% Sungbae An
y = -gammaln(a) -a*log(b)+ (a-1)*log(x) -x/b ;

% inverse gamma
function y = lnpdfig(x,a,b)
% LNPDFIG(X,A,B)
%	calculates log INVGAMMA(A,B) at X

% 03/03/2002
% Sungbae An
y = log(2) - gammaln(b/2) + (b/2)*log(b*a^2/2) - ( (b+1)/2 )*log(x^2) - b*a^2/(2*x^2);


% normal
function y = lnpdfnorm(x,a,b)
% LNPDFNORM(X,A,B)
%	calculates log NORMAL(A,B) at X

% 03/03/2002
% Sungbae An
y = -0.5*log(2*pi) - log(b) - 0.5*(x-a)^2/b^2;