%%
clear
load sw07measurementdata %load data
load pmin_fullspec %load posterior modes and Hessians computed by minimizing appll_sw_post.m using csminwel.m
load startparfull20 %load potential starting values of the parameters (drawn from the prior distribution)
stobs=71; %starting at the same data as SW
x=sw07dat(stobs:end,:); %remove pre-1960 data
n=length(x);
w=2*pi*(1:1:230-stobs)'/n; %define Fourier frequencies (full spectrum)

B=50000; %set number of burn-in values
N=250000; %set number of effective draws in the Markov chain
M=N+B; %total number of draws made


c=[0.15]; %scaling constant for covariance matrix (should be calibrated for rejection rate of 75-77%)

CH=zeros(34,M); %storage for draws


%%
for k=1:length(c)
    sigma=c(k)*pmhess_fi; %proposal covariance matrix (inverse of the Hessian times scaling constant)
parstart=startpar(:,12); %starting value (can choose any of the provided in a matrix)
CH(:,1)=parstart; %initialize the mean of the proposal distribution;
rejc=zeros(M-1,1); %rejection counter storage
probac=zeros(M-1,1); %probability of acceptance
lik=zeros(M,1); 
%detflag=probac;
pflag=probac; %record probability of acceptance (for diagnostic use only)
lik(1,1)=appll_sww(parstart,x,w); %initial likelihood value
rng(46626) %set seed
tic;
for i=2:M
    if mod(i,1000)==0
        i %display counter at each 1000th iteration
    end
    y=mvnrnd(zeros(34,1),sigma,1).' + CH(:,i-1); %draw a parameter vector with previous draw as a mean
    %yy(:,i)=y; %keep draws
    %keeping var-covar matrix the same across all draws
    pflag(i-1,1)=parflag(y); %flags whether some parameters in a draw out of bounds
    
    if pflag(i-1,1)==1
        CH(:,i)=CH(:,i-1); %keep previous draw as some parameter(s) violate bounds
        rejc(i-1,1)=1; %record rejection
        lik(i,1)=lik(i-1,1);

    else
    u=rand(1,1); %generate uniform on (0,1)
    u=log(u); %take log
    %Compute acceptance probability
    
    lik(i,1)=appll_sww(y,x,w); %record likelihood at the draw (diagnostic use)
    
    alpha=lik(i,1) - lik(i-1,1); %ratio of densities
    
    probac(i-1,1)=alpha; %record probability of accepting (diagnostic use)
    
    if u<=alpha
        CH(:,i)=y; %accept draw
        rejc(i-1,1)=0; %record acceptance of the draw
    else
        CH(:,i)=CH(:,i-1); %keep previous draw
        rejc(i-1,1)=1; %record rejection of current draw
        lik(i,1)=lik(i-1,1); %fill in previous likelihood
    end
    end
end
toc;
filename=['mcmc' '_fullupd' num2str(c(k)*100) '_' num2str(46626)]; %create filename for save file
save(filename) %save results
end
