%This uses data in Ni_curves.mat to check if the spectrum stays constant
%along the non-identification curves (as in Tables 2 and 3). 
%Requires gensys package by Sims (2002) and specsol.m to work.
%NB: 1st row of the theta_dir1 matrix corresponds to the original theta0
%parameter vector.

load Ni_curve_SW_1 %load curve points
load Ni_curve_SW_2 %load eigenvalues

n=10000;
k=10; %no of points considered
w=2*pi*(0:1:4999)'/n; %set frequencies to check spectrum at
benchmark=specsol_sw(theta_dir1(1,:),w); % benchmark - spectrum at theta0
maxdev_a1=zeros(k,49); %blanks
maxdev_r1=maxdev_a1;
maxdev_rr1=maxdev_a1;
maxdev_r2=maxdev_a1;
maxdev_a2=maxdev_a1;
maxdev_rr2=maxdev_a1;
windex=maxdev_a1;
%select points in each direction and pick out maximum absolute/relative deviations.
%direction 1:
theta1=theta_dir1([67000:67000:670000]'+1,:); %select ten equally space points along Direction 1
eig1=eig_dir1([67000:67000:670000],:); %select corresponding eigenvalues
for i=1:k
    ad=abs(benchmark-specsol_sw(theta1(i,:),w));
    rd=ad./abs(benchmark);
    maxdev_a1(i,:)=max(ad); %maximum absolute deviations
    maxdev_r1(i,:)=max(rd); %maximum relative deviations
    for j=1:16
     windex(i,j)=max(find(ad(:,j)==max(ad(:,j))));
     maxdev_rr1(i,j) = rd(windex(i,j),j); % maximum absolute deviations in relative form
    end %measure 2 converts maximum abs deviations in maxdev_a1 and converts them into relative 
end
maxa1=sort(maxdev_a1','descend');
maxa1=maxa1(1:10,:)'; %pick out 10 largest absolute deviations from all elements of G(theta)s across all 5000 frequencies

maxrr1=sort(maxdev_rr1','descend');
maxrr1=maxrr1(1:10,:)'; %pick out 10 largest absolute deviations in relative form from all elements of G(theta)s across all 5000 frequencies%direction2:

maxr1=sort(maxdev_r1','descend');
maxr1=maxr1(1:10,:)'; %pick out 10 largest relative deviations from all elements of G(theta)s across all 5000 frequencies

theta2=theta_dir2([47:47:470]',:); %select ten equally space points along Direction 2
eig2=eig_dir2([47:47:470],:); %select corresponding eigenvalues
windex=zeros(k,16);
for i=1:k
    ad=abs(benchmark-specsol_sw(theta2(i,:),w));
    rd=ad./abs(benchmark);
    maxdev_a2(i,:)=max(ad); %maximum absolute deviations
    maxdev_r2(i,:)=max(rd); %maximum relative deviations
    for j=1:16
     windex(i,j)=find(ad(:,j)==max(ad(:,j)));
     maxdev_rr2(i,j) = rd(windex(i,j),j); % maximum absolute deviations in relative form
    end %measure 2 converts maximum abs deviations in maxdev_a1 and converts them into relative 
end

maxa2=sort(maxdev_a2','descend');
maxa2=maxa2(1:10,:)'; %pick out 10 largest absolute deviations from all elements of G(theta)s across all 5000 frequencies

maxrr2=sort(maxdev_rr2','descend');
maxrr2=maxrr2(1:10,:)'; %pick out 10 largest absolute deviations in relative form from all elements of G(theta)s across all 5000 frequencies%direction2:

maxr2=sort(maxdev_r2','descend');
maxr2=maxr2(1:10,:)'; %pick out 10 largest relative deviations from all elements of G(theta)s across all 5000 frequencies

format('short')
disp('Results: Table 1: Parameter values and the corresponding two smallest eigenvalues along the non-identification curve');
disp('     phi      lambda    gamma      beta      delta     eig1     eig2')
disp([theta_dir1(1,[6,8,33,34,35]),eig_dir1(1,:)])
disp('Panel (a): Direction 1')
disp([theta1(:,[6,8,33,34,35]),eig1])
disp('Panel (b): Direction 2')
disp([theta2(:,[6,8,33,34,35]),eig2])


format('short')
disp('Results: Table 2: Deviations of spectra across frequencies (direction 1)');
disp(' 10 largest deviations across frequencies and elements ordered in descending order')
disp('     1          2        3           4        5         6        7        8        9         10')
disp('                                       ')
disp('                  Maximum absolute deviations')
disp(' 10 largest deviations across frequencies and elements ordered in descending order')
disp('     1          2        3           4        5         6        7        8        9         10')
disp(maxa1)
disp('                                       ')
disp('             Maximum absolute deviations in relative form')
disp(' 10 largest deviations across frequencies and elements ordered in descending order')
disp('     1          2        3           4        5         6        7        8        9         10')
disp(maxrr1)
disp('                                       ')
disp('             Maximum relative deviations ')
disp(' 10 largest deviations across frequencies and elements ordered in descending order')
disp('     1          2        3           4        5         6        7        8        9         10')
disp(maxr1)


%
disp('Results: Table 3: Deviations of spectra across frequencies (direction 2)');
disp(' 10 largest deviations across frequencies and elements ordered in descending order')
disp('     1          2        3           4        5         6        7        8        9         10')
disp('                                       ')
disp('                  Maximum absolute deviations')
disp(' 10 largest deviations across frequencies and elements ordered in descending order')
disp('     1          2        3           4        5         6        7        8        9         10')
disp(maxa2)
disp('                                       ')
disp('             Maximum absolute deviations in relative form')
disp(' 10 largest deviations across frequencies and elements ordered in descending order')
disp('     1          2        3           4        5         6        7        8        9         10')
disp(maxrr2)
disp('                                       ')
disp('             Maximum relative deviations ')
disp(' 10 largest deviations across frequencies and elements ordered in descending order')
disp('     1          2        3           4        5         6        7        8        9         10')
disp(maxr2)

