function res = gmatsw(w,theta0,indobs,st)
%This function computes the G matrix for identification from  2
%order properties.
%Note inputs to the function:
%w - vector of Fourier frequencies at which the integrals in G are
%approximated
%
%theta0 - parameter values at which local identification is checked
%
%indobs - index of observables to be used in analysis. [1:7] includes all
%observables in SW 2007.
%index numbers correspond to the ordering of equations in gensys, i.e.:
%1-consumption first difference, 2 - investment first difference, 3 - production (y) first difference,
%4 - labor level (l), 5 - inflation level, 6 - wage first difference, 7 - interest rate level 

%
%
%st - determines numerical derivative step size, which is h=ones(nt,1)*theta0;
%% load parameters

cgy=theta0(1);
cmaw=theta0(2);
cmap=theta0(3);
calfa=theta0(4);
czcap=theta0(5);
csadjcost=theta0(6);
csigma=theta0(7);
chabb=theta0(8);
cfc=theta0(9);
cindw=theta0(10);
cprobw=theta0(11);
cindp=theta0(12);
cprobp=theta0(13);
csigl=theta0(14);
crpi=theta0(15);
crdy=theta0(16);
cry=theta0(17);
crr=theta0(18);
crhoa=theta0(19);
crhob=theta0(20);
crhog=theta0(21);
crhoqs=theta0(22);
crhoms=theta0(23);
crhopinf=theta0(24);
crhow=theta0(25);
sigma_a=theta0(26);
sigma_b=theta0(27);
sigma_g=theta0(28);
sigma_qs=theta0(29);
sigma_m=theta0(30);
sigma_pinf=theta0(31);
sigma_w=theta0(32);
cgamma=theta0(33);
cbeta=theta0(34);
ctou=theta0(35);
cg=theta0(36);
clandaw=theta0(37);
curvp=theta0(38);
curvw=theta0(39);

%compute parameters derived from steady state
ssdpar; %see ssdpar.m
%% 
% % number equations
eqvarshock;  %see eqvarshock.m

%%
setsimsmat; %get sims representation
%% call gensys
[T1,TC,T0,M,TZ,TY,GEV,RC] = gensys(GAM0,GAM1,CS,PSI,PPI);
% reduced form state equation: z(t) = TC + T1 z(t-1) + T0 u(t)

 
  %% Compute spectrum using theta0 at all frequencies
ny=length(indobs); %number of observables used
spec=zeros(ny*length(w),ny);
matB=eye(neq);
matA=matB(18:24,:); %initialize selection matrix
i=1;
while i<=length(w); %loop computes spectra and stacks them in 1 big matrix
    exe=exp(-1i*w(i));
    matA(:,[18:20,23])=matA(:,[18:20,23])*(1-exe); %select appropriate first differences
    matA=matA(indobs,:); %keep only the observables we are interested in
    fact1=matA*((eye(neq) - T1*exe)\T0);
spec(((i-1)*ny+1):(i*ny),:)=(1/(2*pi))*(fact1*fact1'); %compute spectrum using representation (4) in the paper
i=i+1;
matA=matB(18:24,:); %restore initial A
end;

nt=length(theta0);

%% Numerical derivatives (simple two-point method)
dspec=zeros(ny*length(w),ny*nt);
h=theta0*st; %numerical differentiation step
j=1;
while j<=nt; %the loop computes spectra at a perturbed theta vector
    theta1=theta0;
    %h(j)=max(h(j),1e-9);
    theta0(j)=theta1(j)+h(j);
   
%replaced constebeta by cbeta
cgy=theta0(1);
cmaw=theta0(2);
cmap=theta0(3);
calfa=theta0(4);
czcap=theta0(5);
csadjcost=theta0(6);
csigma=theta0(7);
chabb=theta0(8);
cfc=theta0(9);
cindw=theta0(10);
cprobw=theta0(11);
cindp=theta0(12);
cprobp=theta0(13);
csigl=theta0(14);
crpi=theta0(15);
crdy=theta0(16);
cry=theta0(17);
crr=theta0(18);
crhoa=theta0(19);
crhob=theta0(20);
crhog=theta0(21);
crhoqs=theta0(22);
crhoms=theta0(23);
crhopinf=theta0(24);
crhow=theta0(25);
sigma_a=theta0(26);
sigma_b=theta0(27);
sigma_g=theta0(28);
sigma_qs=theta0(29);
sigma_m=theta0(30);
sigma_pinf=theta0(31);
sigma_w=theta0(32);
cgamma=theta0(33);
cbeta=theta0(34);
ctou=theta0(35);
cg=theta0(36);
clandaw=theta0(37);
curvp=theta0(38);
curvw=theta0(39);
%same as before code follows for each iteration
ssdpar;

%% Initialize Matrices
setsimsmat;
%% call gensys
[T1,TC,T0,M,TZ,TY,GEV,RC] = gensys(GAM0,GAM1,CS,PSI,PPI);

i=1;
while i<=length(w); %loop computes spectra and stacks them in 1 big matrix
    exe=exp(-1i*w(i));
    matA(:,[18:20,23])=matA(:,[18:20,23])*(1-exe);
    matA=matA(indobs,:);
    fact1=matA*((eye(neq) - T1*exe)\T0);
   
    dspec((i-1)*ny+1:i*ny,(j-1)*ny+1:j*ny)=(1/(2*pi))*(fact1*fact1'); %compute spectrum using representation (4) in the paper
i=i+1;
matA=matB(18:24,:);
end; 
theta0=theta1;
j=j+1;
end;
nt=length(theta0);

G=zeros(nt,nt);
j=1;
while j<=nt; %computing G using representation in Remark 3 and approximating the integral numerically
    k=1;
    while k<=nt;
       aj=(dspec(:,((j-1)*ny+1):(j*ny))-spec)/h(j);
       ak=(dspec(:,((k-1)*ny+1):(k*ny))-spec)/h(k); 
       f=1;
   while f<=length(w);
G(j,k)=G(j,k)+trace(aj(((f-1)*ny+1):(f*ny),:)*ak(((f-1)*ny+1):(f*ny),:));
f=f+1;
   end  
   k=k+1;
    end
    j=j+1;
end
G2=2*pi*G./10000; %assuming approximation of the integral with 10000 points 

res=G2;
end