function res = musym_sw(theta0,indobs)
%Computes analytical exression for the mu term for SW 2007, and evaluates
%at a given theta0.
%
%Inputs:
%theta0 - parameter vector at which identification is being checked
%indobs - index of observables to be used in analysis. [1:7] includes all
%observables in SW 2007.
%index numbers correspond to the ordering of equations in gensys, i.e.:
%1-consumption first difference, 2 - investment first difference, 3 - production (y) first difference,
%4 - labor level (l), 5 - inflation level, 6 - wage first difference, 7 - interest rate level 

%% Symbolic set-up
syms cgy cmaw cmap calfa ...
czcap csadjcost csigma chabb cfc cindw cprobw cindp cprobp csigl crpi crdy cry crr ...
crhoa crhob crhog crhoqs crhoms crhopinf crhow ...
sigma_a sigma_b sigma_g sigma_qs sigma_m sigma_pinf sigma_w cgamma  cbeta ctou cg clandaw curvp curvw constepinf constelab
%set up full mu term
mu=[(cgamma-1)*100;(cgamma-1)*100;(cgamma-1)*100;constelab;constepinf;(cgamma-1)*100;100*((1/cbeta)*(cgamma^csigma)*(1+constepinf/100) - 1)];
mu=mu(indobs,1); %select specified observables from the full term
%% Symbolic computation
 %get symbolic theta0
theta=[cgy,cmaw,cmap,calfa,...
czcap,csadjcost,csigma,chabb,cfc,cindw,cprobw,cindp,cprobp,csigl,crpi,crdy,cry,crr,...
crhoa,crhob,crhog,crhoqs,crhoms,crhopinf,crhow,...
sigma_a,sigma_b,sigma_g,sigma_qs,sigma_m,sigma_pinf,sigma_w,cgamma, cbeta,ctou,cg,clandaw,curvp,curvw,constepinf,constelab];
jac=jacobian(mu,theta); %jacobian of mu
mujac=jac.'*jac; %get symbolic mu term
%% Evaluate results
%Only 4 parameters necessary to evaluate:
csigma=theta0(7);

cgamma=theta0(33);

cbeta=theta0(34);

constepinf=theta0(40);

res = eval(mujac);
end