%% Analysis of model spectra and coherence
clear
v1='Consumption growth';
v2='Investment growth';
v3='Output growth';
v4='Labor hours';
v5='Inflation';
v6='Wage growth';
v7='Interest rate';
w=[0:1:80]'*2*pi./160; %Fourier freq
f=w./(2*pi); %cycles per period
load postmodes %load posterior modes
load sw07measurementdata
x=sw07dat(71:end,:); %get post-1960 data
spdf=specd_sw(pmode_f,w); %theoretical spectra at posterior modes
spdbc=specd_sw(pmode_bc,w);
dx=x-kron(mean(x),ones(160,1)); %demeaned data


for i=1:7
    specmodf(:,i)=spdf(:,1+8*(i-1)); %model spectra at full spectrum parameter estimates 
    specmodbc(:,i)=spdbc(:,1+8*(i-1)); %same but for bc parameter estimates

    [sper CI]=smoothper(dx(:,i),danielk([1/3,1/7],0),0); %smoothed periodogram estimate and confidence bounds
    [sperl CIl]=smoothper(dx(:,i),danielk([1/3,1/7],0),1); %for log spectra
    specsm(:,i)=sper;
    specsmhi(:,i)=CI(:,2);
    specsmlo(:,i)=CI(:,1);
        specsml(:,i)=sperl; %log spectra
    specsmhil(:,i)=CIl(:,2);
    specsmlol(:,i)=CIl(:,1);
end

ww=danielk([1/3,1/7],0); %smoothing filter window

%Figure 5: Model vs. data spectra
figure(4) %to avoid overwriting by future figures
for i=1:7
subplot(3,3,i); plot(f(2:end-1),log(specmodf(2:end-1,i)),'Color','k','Linestyle','-','LineWidth',2);%,f,specmodbc(:,i),'Color','k','Linestyle','--',f,specdata(:,i),'Color','k','Linestyle','-.');
axis([0 max(f(2:end-1)) min(specsmlol(2:end-1,i)) max(specsmhil(:,i))]);
gridxy([f(6) f(27)],'Color','k','Linestyle','--') ;
hold on
plot(f(2:end-1),log(specmodbc(2:end-1,i)),'Color','k','Linestyle','--','LineWidth',2);
plot(f(2:end-1),specsml(2:end-1,i),'Color','k','Linestyle','-.','LineWidth',2);
ciplot(specsmlol(2:end-1,i),specsmhil(2:end-1,i),f(2:end-1),[0.5 0.5 0.5]);
alpha(0.5)

title(['Spectral densities (log scale) of ' eval(['v' num2str(i)])])

end
legend('BC frequencies', 'Model psd using full spectrum','Model psd using BC only','Data spectrum estimate','95% CI for spectrum estimate')
%%
ind=nchoosek([1:7],2);
for i=1:21
    coherf(:,i)=(spdf(2:end,ind(i,2)+7*(ind(i,1)-1)).*conj(spdf(2:end,ind(i,2)+7*(ind(i,1)-1))))./(specmodf(2:end,ind(i,1)).*specmodf(2:end,ind(i,2))); %model coherency (full spectrum)
    coherbc(:,i)=(spdbc(2:end,ind(i,2)+7*(ind(i,1)-1)).*conj(spdbc(2:end,ind(i,2)+7*(ind(i,1)-1))))./(specmodbc(2:end,ind(i,1)).*specmodbc(2:end,ind(i,2))); %model coherency (business cycle)
    [COH CIC]= cohers(dx(:,ind(i,1)),dx(:,ind(i,2)),ww); %smoothed coherency estimates
    cohersm(:,i)=COH;
    cohersmlo(:,i)=CIC(:,1); %confidence bounds
    cohersmhi(:,i)=CIC(:,2);
end

for j=1:21
    for i=1:81
        if cohersmlo(i,j)<0
            cohersmlo(i,j)=0; %truncate lower band at zero (as absolute coherency cannot be negative)
        end
    end
end
%Figure 5(a)-(c): absolute coherency of model and data spectra
for j=1:3
    figure(j)
for i=1:7
  

subplot(4,2,i); plot(f(2:49),sqrt(coherf(1:48,i+7*(j-1))),'Color','k','Linestyle','-','LineWidth',1);
axis([0 max(f(2:49)) min(cohersmlo(2:49,i+7*(j-1))) max(cohersmhi(2:49,i+7*(j-1)))]);
gridxy([f(6) f(27)],'Color','k','Linestyle','--') ;
hold on
plot(f(2:49),sqrt(coherbc(1:48,i+7*(j-1))),'Color','k','Linestyle','--','LineWidth',1);
plot(f(2:49),cohersm(2:49,i+7*(j-1)),'Color','k','Linestyle','-.','LineWidth',1);
ciplot(cohersmlo(2:49,i+7*(j-1)),cohersmhi(2:49,i+7*(j-1)),f(2:49),[0.5 0.5 0.5]);
alpha(0.5)
title([ eval(['v' num2str(ind(i+7*(j-1),1))]) ' and ' eval(['v' num2str(ind(i+7*(j-1),2))])])
xlabel('cycles per quarter')
ylabel('absolute coherency')
%ct = camtarget;
%camtarget([ct(1)+0.001*ct(1) ct(2)+0.001 ct(3)]);
end
legend('BC frequencies interval', 'Model implied coherency (at full spectrum parameter estimates)','Model implied coherency (at BC frequencies only parameter estimates)','Nonparametric estimate of coherency', '95% Confidence interval based on the nonparametric estimate')
end